@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-# $Revision: 998 $ - $Date: 2007-07-06T00:30:49.463277Z $
+# $Revision: 452 $ - $Date: 2006-08-08T01:37:17.051641Z $
 
 =pod 
 
@@ -37,8 +37,8 @@ XML::XPathScript - a Perl framework for XML stylesheets
   my $xps = XML::XPathScript->new;
   $xps->compile( qw/ $foo $bar / );
 
-           # in stylesheet, $foo will be set to 'a'
-           # and $bar to 'b'
+                                    # in stylesheet, $foo is 'a'
+                                    # and $bar is 'b'
   $xps->transform( $xml, $stylesheet, [ 'a', 'b' ] ); 
 
 =head1 DESCRIPTION
@@ -75,11 +75,11 @@ via the command line.
 
 Those methods are meants to be used from within a stylesheet.
 
-=head2 current
+=over
 
-    $xps = XML::XPathScript->current
+=item I<current()>
 
-This class method returns
+This class method (e.g. C<< XML::XPathScript->current() >>) returns
 the stylesheet object currently being applied. This can be called from
 anywhere within the stylesheet, except a BEGIN or END block or
 similar. B<Beware though> that using the return value for altering (as
@@ -95,10 +95,10 @@ sub current {
     return $XML::XPathScript::current;
 }
 
-=head2 interpolation 
+=item interpolation 
 
-    $interpolate = $XML::XPathScript::current->interpolation
-    $interpolate = $XML::XPathScript::current->interpolation( $boolean )
+        $XML::XPathScript::current->interpolation()
+        $XML::XPathScript::current->interpolation( $boolean )
 
 Gets (first call form) or sets (second form) the XPath interpolation
 boolean flag. If true, values set in C< pre > and C< post >
@@ -115,8 +115,8 @@ The interpolation-less version is slightly more complex as it requires a
 C<testcode>:
 
    sub link_testcode  {
-      my ($node, $t) = @_;
-      my $url = $node->findvalue('@url');
+      my ($currentnode, $t) = @_;
+      my $url = findvalue('@url', $currentnode);
       $t->set({ pre  => "<a href='$url'>",
                 post => "</a>"             });
 	  return DO_SELF_AND_KIDS();
@@ -134,19 +134,17 @@ sub interpolation {
 sub interpolating {
     my $self=shift;
 
-    if ( @_ ) {
-        $self->processor->set_interpolation( 
-            $self->{interpolating} = shift
-        );
-    }
+    $self->{interpolating}=shift if (@_);
 
-    return $self->{interpolating} || 0;
+    return exists $self->{interpolating} ?
+			$self->{interpolating} :
+		    !$XML::XPathScript::DoNotInterpolate; # Obsolete, for compatibility:
 }
 
-=head2 interpolation_regex
+=item interpolation_regex
 
-    $regex = $XML::XPathScript::current->interpolation_regex
-    $XML::XPathScript::current->interpolation_regex( $regex )
+    $regex = $XML::XPathScript::curent->interpolation_regex()
+    $XML::XPathScript::curent->interpolation_regex( $regex )
 
 Gets or sets the regex to use for interpolation. The value to be 
 interpolated must be capture by $1. 
@@ -164,17 +162,15 @@ Example:
 sub interpolation_regex {
     my $self = shift;
 
-    if ( my $regex = shift ) {
-        $self->processor->set_interpolation_regex( 
-            $self->{interpolation_regex} = $regex
-        )
-    }
+    $self->{interpolation_regex} = shift if @_;
 
     return $self->{interpolation_regex};
 }
 
 
-=head2 binmode
+=pod "
+
+=item I<binmode()>
 
 Declares that the stylesheet output is B<not> in UTF-8, but instead in
 an (unspecified) character encoding embedded in the stylesheet source
@@ -188,13 +184,14 @@ Unicode mess>.
 sub binmode {
     my ($self)=@_;
     $self->{binmode}=1;
-    $self->{processor}->enable_binmode;
     binmode ORIGINAL_STDOUT if (! defined $self->{printer});
     return;
 }
 
 =pod "
 
+=back
+
 =head1 TECHNICAL DOCUMENTATION
 
 The rest of this POD documentation is B<not> useful to programmers who
@@ -232,31 +229,19 @@ preprocess time.
 
 =cut "
 
-use vars qw( $XML_parser $debug_level );
+use vars qw( $XML_parser $DoNotInterpolate $debug_level );
 
 use Symbol;
 use File::Basename;
 use XML::XPathScript::Processor;
 use XML::XPathScript::Template;
 
-our $VERSION = '1.50.1';
+our $VERSION = '1.45';
 
 $XML_parser = 'XML::LibXML';
 
-my %use_parser = (
-    'XML::LibXML' => 'use XML::LibXML',
-    'XML::XPath' => <<'END_USE',
-			use XML::XPath 1.0;
-			use XML::XPath::XMLParser;
-			use XML::XPath::Node;
-			use XML::XPath::NodeSet;
-			use XML::Parser;
-END_USE
-);
-
-die "parser $XML_parser unknown\n" unless $use_parser{$XML_parser};
-eval $use_parser{$XML_parser}.";1" 
-    or die "couldn't import $XML_parser";
+# By default, we interpolate
+$DoNotInterpolate = 0;
 
 # internal variable for debugging information. 
 # 0 is total silence and 10 is complete verbiage
@@ -275,13 +260,34 @@ sub import
     return;
 }
 
+INIT
+{
+	if( $XML_parser eq 'XML::XPath' )
+	{
+		eval <<'EOT';
+			use XML::XPath 1.0;
+			use XML::XPath::XMLParser;
+			use XML::XPath::Node;
+			use XML::XPath::NodeSet;
+			use XML::Parser;
+EOT
+		die $@ if $@;
+	}
+	else
+	{
+		eval 'use XML::LibXML';
+		die $@ if $@;
+	}
+
+}
+
 =pod "
 
 =head1 METHODS
 
-=head2 new
+=over
 
-    $xps = XML::XPathScript->new( %arguments )
+=item I<< new(key1=>value1,key2=>value2,...) >>
 
 Creates a new XPathScript translator. The recognized named arguments are
 
@@ -321,7 +327,7 @@ documents in a row.
 
 =item interpolation_regex => $regex
 
-Sets the interpolation regex. Whatever is
+Sets the interpolation regex to be $regex. Whatever is
 captured in $1 will be used as the xpath expression. 
 Defaults to qr/{(.*?)}/.
 
@@ -335,26 +341,20 @@ sub new {
     my %params = @_;
     my $self = \%params;
     bless $self, $class;
-    $self->{processor} = XML::XPathScript::Processor->new;
     $self->set_xml( $params{xml} ) if $params{xml};
-
-    $self->interpolation( exists $params{interpolation} 
-                               ? $params{interpolation} : 1 );
-
-    $self->interpolation_regex( $params{interpolation_regex} 
-                                || qr/{(.*?)}/ );
-
-
+	$self->{interpolation_regex} ||= qr/{(.*?)}/;
 
     if (  $XML::XPathScript::XML_parser eq 'XML::XPath' ) {
-        require XML::XPath;
-        require XML::XPath::XMLParser;
-        require XML::XPath::Node;
-        require XML::XPath::NodeSet;
-        require XML::Parser;
+        eval <<END_EVAL;
+			use XML::XPath 1.0;
+			use XML::XPath::XMLParser;
+			use XML::XPath::Node;
+			use XML::XPath::NodeSet;
+			use XML::Parser;
+END_EVAL
     } 
     else {
-        require XML::LibXML;
+        eval 'use XML::LibXML';
     }
 
     croak $@ if $@;
@@ -362,14 +362,12 @@ sub new {
     return $self;
 }
 
-=head2 transform
-
-    $xps->transform( $xml, $stylesheet, \@args )
+=item I<transform( $xml, $stylesheet, \@args )>
 
 Transforms the document $xml with the $stylesheet (optionally passing to
 the stylesheet the argument array @args) and returns the result.
 
-If the passed $xml or $stylesheet is undefined, the previously loaded xml 
+If the passed $xml or $stylesheet is undef, the previously loaded xml 
 document or stylesheet is used.
 
 E.g.,
@@ -411,26 +409,7 @@ sub transform {
     return $output;
 }
 
-=head2 set_dom
-
-    $xps->set_dom( $dom )
-
-Set the DOM of the document to process. I<$dom>
-must be a node object of one of the supported 
-parsers (XML::LibXML, XML::XPath, B::XPath).
-
-=cut
-
-sub set_dom {
-    my( $self, $dom ) = @_;
-    $self->{dom} = $dom;
-    $self->{processor}->set_dom( $dom );
-    return $self;
-}
-
-=head2 set_xml
-
-    $xps->set_xml( $xml )
+=item I<set_xml( $xml )>
 
 Sets the xml document to $xml. $xml can be a file, a file handler 
 reference, a string, or a XML::LibXML or XML::XPath node.
@@ -442,15 +421,7 @@ sub set_xml {
 
     $self->{xml} = $xml;
 
-    my $retval = ref $xml ? $self->_set_xml_ref() 
-                          : $self->_set_xml_scalar()
-                          ;
-
-    $self->{processor}->set_dom( $self->{dom} );
-    
-    return $retval;
-
-    # FIXME
+    return ref $xml ? $self->_set_xml_ref() : $self->_set_xml_scalar();
 
 my $xpath;
 
@@ -577,9 +548,7 @@ sub _set_xml_scalar {
     return;
 }
 
-=head2 set_stylesheet
-
-    $xps->set_stylesheet( $stylesheet )
+=item I<set_stylesheet( $stylesheet )>
 
 Sets the processor's stylesheet to $stylesheet.
 
@@ -596,29 +565,26 @@ sub set_stylesheet {
 
 =pod "
 
-=head2 process
+=item I<process()>
 
-    $xps->process
-    $xps->process( $printer )
-    $xps->process( $printer, @varvalues )
+=item I<process($printer)>
+
+=item I<process($printer,@varvalues)>
 
 Processes the document and stylesheet set at construction time, and
 prints the result to STDOUT by default. If $printer is set, it must be
 either a reference to a filehandle open for output, or a reference to
 a string, or a reference to a subroutine which does the output, as in
 
-    open my $fh, '>', 'transformed.txt' 
-        or die "can't open file transformed.txt: $!";
-    $xps->process( $fh );
+   my $buffer="";
+   $xps->process(sub {$buffer.=shift;});
 
-    my $transformed;
-    $xps->process( \$transformed );
+or
 
-    $xps->process( sub { 
-        my $output = shift;
-        $output =~ y/<>/%%/;
-        print $output;
-    } );
+   $xps->process(sub {print ANOTHERFD (shift);});
+
+(not that the latter would be any good, since 
+C< $xps->process(\*ANOTHERFD) > would do exactly the same, only faster)
 
 If the stylesheet was I<compile()>d with extra I<varname>s, then the
 calling code should call I<process()> with a corresponding number of
@@ -637,8 +603,7 @@ sub process {
 
     croak "xml document not defined" unless $self->{dom};
 
-    # FIXME
-	eval { $self->{dom}->ownerDocument->setEncoding( "UTF-8" ) }
+	$self->{dom}->ownerDocument->setEncoding( "UTF-8" ) 
 		if $XML_parser eq 'XML::LibXML';
 
 	{
@@ -657,11 +622,13 @@ sub process {
 	}
 }
 
-=head2 extract
+=pod "
 
-    $xps->extract( $stylesheet )
-    $xps->extract( $stylesheet, $filename )
-    $xps->extract( $stylesheet, @includestack ) # from include_file() only
+=item I<extract($stylesheet)>
+
+=item I<extract($stylesheet,$filename)>
+
+=item I<extract($stylesheet,@includestack)> # from include_file() only
 
 The embedded dialect parser. Given $stylesheet, which is either a
 filehandle reference or a string, returns a string that holds all the
@@ -698,94 +665,6 @@ sub extract {
 
     my $contents = $self->read_stylesheet( $stylesheet );
 
-    my @tokens = split /(<%[-=~#@]*|-?%>)/, $contents;
-
-    no warnings qw/ uninitialized /;
-
-    my $script;
-    my $line = 1;
-    TOKEN:
-    while ( @tokens ) {
-        my $token = shift @tokens;
-
-        if ( -1 == index $token, '<%' ) {
-            $line += $token =~ tr/\n//;
-            $token =~ s/\s+$// if  -1 < index $tokens[0], '<%'
-                               and -1 < index $tokens[0], '-';
-            $token =~ s/\|/\\\|/g;
-            # check for include
-            $token =~ s{<!--#include.+file=(['"])(.*?)\1.*?-->}
-                       { '|);'
-                         . $self->include_file( $2, @includestack)
-                         . 'print(q|'}seg;
-            $script .= 'print(q|'.$token.'|);' if length $token;
-
-            next TOKEN;
-        }
-
-        $script .= "\n#line $line $filename\n";
-
-        my $opening_tag = $token;
-        my $code;
-        my $closing_tag;
-        my $level = 1;
-        while( @tokens ) {
-            my $t = shift @tokens;
-            $level++ if -1 < index $t, '<%';
-            $level-- if -1 < index $t, '%>';
-            if ( $level == 0 ) {
-                $closing_tag = $t;
-                last;
-            }
-            $code .= $t;
-        }
-
-        die "stylesheet <% %>s are unbalanced: $opening_tag$code\n"
-            unless $closing_tag;
-
-        $line += $code =~ tr/\n//;
-
-        if ( -1 < index $opening_tag, '=' ) {
-            $script .= 'print( '.$code.' );';
-        }
-        elsif ( -1 < index $opening_tag, '~' ) {
-            $code =~ s/^\s+//; 
-            $code =~ s/\s+$//; 
-            $script .= 'print $processor->apply_templates( qq<'. $code .'> );';
-        }
-        elsif( -1 < index $opening_tag, '#' ) {
-            # do nothing
-        }
-        elsif( -1 < index $opening_tag, '@' ) {
-            $code =~ s/^\s+(\S+).*?\n//;    # strip first line
-            my $tag = $1 
-                or die "tag name missing in <%\@ %> at line $line\n";
-
-            my $here_delimiter = 'END_TAG';
-            while ( $code =~ /$here_delimiter/ ) {
-                $here_delimiter .= 'x';
-            }
-            $script .= <<END_SNIPPET;
-\$template->set( $tag => { content => <<'$here_delimiter' } );
-$code
-$here_delimiter
-END_SNIPPET
-        }
-        else {
-                    # always add a ';', just in case
-            $script .= $code . ';';
-        }
-
-        if ( -1 < index $closing_tag, '-' ) {
-            $tokens[0] =~ s/^\s*//;
-            my $temp = $&;
-            $line += $temp =~ tr/\n//;
-        }
-    }
-
-    return $script;
-
-    # FIXME not needed anymore
     # <%- -%> magic
     $contents =~ s#(\s+)<%-([=~]?)#<%$2$1#gs;
     $contents =~ s#-%>(\s+)#$1%>#gs;
@@ -793,8 +672,8 @@ END_SNIPPET
     # <%~ %> magic
     $contents =~ s#<%~\s+(\S+)\s+%>#<%= apply_templates( qq<$1> ) %>#gs;
 
-    $script="#line 1 $filename\n",
-    $line = 1;
+    my $script="#line 1 $filename\n",
+    my $line = 1;
 
     while ($contents =~ /\G(.*?)(<!--#include|<%[=#]?)/gcs) {
         my ($text, $type) = ($1, $2);
@@ -841,9 +720,9 @@ END_SNIPPET
     return $script;
 }
 
-=head2 read_stylesheet
+=pod "
 
-    $string = $xps->read_stylesheet( $stylesheet )
+=item $string = I<read_stylesheet( $stylesheet )>
 
 Read the $stylesheet (which can be a filehandler or a string). 
 Used by I<extract> and exists such that it can be overloaded in
@@ -867,10 +746,11 @@ sub read_stylesheet
 	
 }
 
-=head2 include_file
+=pod "
 
-    $xps->include_file( $filename )
-    $xps->include_file( $filename, @includestack )
+=item I<include_file($filename)>
+
+=item I<include_file($filename,@includestack)>
 
 Resolves a C<< <!--#include file="foo" --> >> directive on behalf of
 I<extract()>, that is, returns the script contents of
@@ -935,17 +815,17 @@ sub include_file {
 
 =pod "
 
-=head2 I<compile()>
+=item I<compile()>
 
-=head2 I<compile(varname1, varname2,...)>
+=item I<compile(varname1, varname2,...)>
 
 Compiles the stylesheet set at I<new()> time and returns an anonymous
 CODE reference. 
 
 I<varname1>, I<varname2>, etc. are extraneous arguments that will be
 made available to the stylesheet dialect as lexically scoped
-variables. L</SYNOPSIS> shows how to use this feature to pass variables
-to AxKit XPathScript stylesheets, which explains this
+variables. L</SYNOPSIS> shows a way to use this feature to pass the
+Apache handler to AxKit XPathScript stylesheets, which explains this
 feature better than a lengthy paragraph would do.
 
 The return value is an opaque token that encapsulates a compiled
@@ -992,13 +872,6 @@ sub compile {
     my $package=gen_package_name();
 
 	my $extravars = join ',', @extravars;
-
-    my $processor = $self->{processor};
-
-    # needs to be eval'ed first for the constants
-    # to be seen
-    eval "package $package;"
-        ."\$processor->import_functional();";
 	
 	my $eval = <<EOT;
 		    package $package;
@@ -1006,21 +879,17 @@ sub compile {
 		    no warnings; # written stylesheets
 			
 			use $XML_parser;  
-
+		    BEGIN {XML::XPathScript::Processor->import;}
 		    sub {
 		    	my (\$self, $extravars ) = \@_;
-                my \$processor = processor();
 				local \$XML::XPathScript::current=\$self;
-		    	my \$t = \$processor->{template} 
+		    	my \$t = \$XML::XPathScript::current->{t} 
                             = XML::XPathScript::Template->new();
                 my \$template = \$t;
-                local \$XML::XPathScript::trans = \$t;
-                #\$processor->{doc} = \$self->{dom};
-                #\$processor->{parser} = '$XML_parser';
-                #\$processor->{binmode} = \$self->{binmode};
-                #\$processor->{is_interpolating} = \$self->interpolation;
-                #\$processor->{interpolation_regex} = \$self->interpolation_regex;
-
+				local \$XML::XPathScript::trans = \$t; # Yes,
+				# this does the sharing! Perl is a bizarre and
+				# wonderful language.
+				local \$XML::XPathScript::xp=\$self->{dom};
 				$script
 		    }
 EOT
@@ -1035,9 +904,9 @@ EOT
 }
 
 
-=head2 print
 
-    $xps->print($text)
+
+=item I<print($text)>
 
 Outputs a chunk of text on behalf of the stylesheet. The default
 implementation is to use the second argument to L</process>. 
@@ -1047,7 +916,6 @@ method in a subclass provides yet another method to redirect output.
 =cut "
 
 sub print {
-    no warnings qw/ uninitialized /;
     my ($self, @text)=@_;
     my $printer=$self->{printer};
 
@@ -1073,9 +941,7 @@ sub debug {
 	warn $_[2] if $_[1] <= $debug_level;
 }
 
-=head2 get_stylesheet_dependencies
-
-    @files = $xps->get_stylesheet_dependencies
+=item I<get_stylesheet_dependencies()>
 
 Returns the files the loaded stylesheet depends on (i.e., has been
 included by the stylesheet or one of its includes). The order in which
@@ -1089,24 +955,18 @@ sub get_stylesheet_dependencies {
     return sort keys %{$self->{stylesheet_cache}};
 }
 
-=head2 processor
+=pod "
 
-    $processor = $xps->processor
-
-Returns the processor object associated with I<$xps>.
-
-=cut
-
-sub processor {
-    return $_[0]->{processor};
-}
+=back
 
 =head1 FUNCTIONS
 
-#=head2 gen_package_name
-#
-#Generates a fresh package name in which we would compile a new
-#stylesheet. Never returns twice the same name.
+=over
+
+=item I<gen_package_name()>
+
+Generates a fresh package name in which we would compile a new
+stylesheet. Never returns twice the same name.
 
 =cut "
 
@@ -1118,9 +978,7 @@ sub gen_package_name {
 }
 };
 
-=head2 document
-
-    $nodeset = $xps->document( $uri )
+=item  $nodeset = $xps->document( $uri )
 
 Reads XML given in $uri, parses it and returns it in a nodeset.
 
@@ -1205,6 +1063,8 @@ sub BINMODE {
 
 __END__
 
+=back
+
 =head1 BUGS
 
 Please send bug reports to <bug-xml-xpathscript@rt.cpan.org>,
@@ -1216,17 +1076,10 @@ http://rt.cpan.org/Public/Dist/Display.html?Name=XML-XPathScript .
 
 Current maintainers: 
 Yanick Champoux <yanick@cpan.org> 
-and Dominique Quatravaux <domq@cpan.org>
+and Dominique Quatravaux <dom@idealx.com>
 
 Created by Matt Sergeant <matt@sergeant.org>
 
-=head1 THANKS
-
-Thanks to Tim Nelson for pretty nifty suggestions and 
-patches. We sure hope the new B<insteadofchildren>
-tag will make XSL users flock to XPS like ants to 
-a melting chocolate bunny, as he promised. ;-)
-
 =head1 LICENSE
 
 This is free software. You may distribute it under the same terms as
